@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -53,6 +53,7 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/monitor-private.h"
+#include "magick/pixel-accessor.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -117,10 +118,6 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     sans,
     status;
 
-  ssize_t
-    x,
-    y;
-
   Pixmap
     pixmap;
 
@@ -139,6 +136,10 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   Screen
     *screen;
 
+  ssize_t
+    x,
+    y;
+
   XColor
     *colors;
 
@@ -382,11 +383,11 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
           {
             pixel=XGetPixel(dps_image,x,y);
             index=(pixel >> red_shift) & red_mask;
-            q->red=ScaleShortToQuantum(colors[index].red);
+            SetPixelRed(q,ScaleShortToQuantum(colors[index].red));
             index=(pixel >> green_shift) & green_mask;
-            q->green=ScaleShortToQuantum(colors[index].green);
+            SetPixelGreen(q,ScaleShortToQuantum(colors[index].green));
             index=(pixel >> blue_shift) & blue_mask;
-            q->blue=ScaleShortToQuantum(colors[index].blue);
+            SetPixelBlue(q,ScaleShortToQuantum(colors[index].blue));
             q++;
           }
           if (SyncAuthenticPixels(image,exception) == MagickFalse)
@@ -405,13 +406,15 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
             pixel=XGetPixel(dps_image,x,y);
             color=(pixel >> red_shift) & red_mask;
             color=(color*65535L)/red_mask;
-            q->red=ScaleShortToQuantum((unsigned short) color);
+            SetPixelRed(q,ScaleShortToQuantum((unsigned short) color));
             color=(pixel >> green_shift) & green_mask;
             color=(color*65535L)/green_mask;
-            q->green=ScaleShortToQuantum((unsigned short) color);
+            SetPixelGreen(q,ScaleShortToQuantum((unsigned short)
+              color));
             color=(pixel >> blue_shift) & blue_mask;
             color=(color*65535L)/blue_mask;
-            q->blue=ScaleShortToQuantum((unsigned short) color);
+            SetPixelBlue(q,ScaleShortToQuantum((unsigned short)
+              color));
             q++;
           }
           if (SyncAuthenticPixels(image,exception) == MagickFalse)
@@ -453,7 +456,8 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
         indexes=GetAuthenticIndexQueue(image);
         for (x=0; x < (ssize_t) image->columns; x++)
-          indexes[x]=(unsigned short) XGetPixel(dps_image,x,y);
+          SetPixelIndex(indexes+x,(unsigned short)
+            XGetPixel(dps_image,x,y));
         if (SyncAuthenticPixels(image,exception) == MagickFalse)
           break;
         if (SetImageProgress(image,LoadImageTag,y,image->rows) == MagickFalse)
@@ -498,9 +502,9 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   break;
                 for (x=0; x < (ssize_t) image->columns; x++)
                 {
-                  SetOpacityPixelComponent(q,OpaqueOpacity);
+                  SetPixelOpacity(q,OpaqueOpacity);
                   if (XGetPixel(matte_image,x,y) == 0)
-                    q->opacity=TransparentOpacity;
+                    SetPixelOpacity(q,TransparentOpacity);
                   q++;
                 }
                 if (SyncAuthenticPixels(image,exception) == MagickFalse)
