@@ -38,14 +38,17 @@
  */
 
 #include "magick/studio.h"
-#if defined(MAGICKCORE_WINGDI32_DELEGATE)
+#if defined(MAGICKCORE_WINGDI32_DELEGATE) && defined(__CYGWIN__)
+#  define MAGICKCORE_EMF_DELEGATE
+#endif
+
+#if defined(MAGICKCORE_EMF_DELEGATE)
 #  if defined(__CYGWIN__)
 #    include <windows.h>
 #  else
 #    include <wingdi.h>
 #  endif
 #endif
-
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/cache.h"
@@ -58,6 +61,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/pixel.h"
+#include "magick/pixel-accessor.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -284,7 +288,7 @@ static wchar_t *ConvertUTF8ToUTF16(const unsigned char *source)
   metafile, or an Aldus Placeable metafile and converts it into an enhanced
   metafile.  Width and height are returned in .01mm units.
 */
-#if defined(MAGICKCORE_WINGDI32_DELEGATE)
+#if defined(MAGICKCORE_EMF_DELEGATE)
 static HENHMETAFILE ReadEnhMetaFile(const char *path,ssize_t *width,
   ssize_t *height)
 {
@@ -630,7 +634,7 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
   DeleteObject(hBitmap);
   return(GetFirstImageInList(image));
 }
-#endif /* MAGICKCORE_WINGDI32_DELEGATE */
+#endif /* MAGICKCORE_EMF_DELEGATE */
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -661,7 +665,7 @@ ModuleExport size_t RegisterEMFImage(void)
     *entry;
 
   entry=SetMagickInfo("EMF");
-#if defined(MAGICKCORE_WINGDI32_DELEGATE)
+#if defined(MAGICKCORE_EMF_DELEGATE)
   entry->decoder=ReadEMFImage;
 #endif
   entry->description=ConstantString(
@@ -671,7 +675,7 @@ ModuleExport size_t RegisterEMFImage(void)
   entry->module=ConstantString("WMF");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("WMFWIN32");
-#if defined(MAGICKCORE_WINGDI32_DELEGATE)
+#if defined(MAGICKCORE_EMF_DELEGATE)
   entry->decoder=ReadEMFImage;
 #endif
   entry->description=ConstantString("Windows WIN32 API rendered Meta File");
