@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -43,6 +43,7 @@
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/cache.h"
+#include "magick/channel.h"
 #include "magick/constitute.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -54,10 +55,11 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/monitor-private.h"
+#include "magick/pixel-accessor.h"
+#include "magick/quantum-private.h"
 #include "magick/random_.h"
 #include "magick/random-private.h"
 #include "magick/signature-private.h"
-#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/module.h"
@@ -114,11 +116,11 @@ static inline void PlasmaPixel(Image *image,RandomInfo *random_info,double x,
   if (q == (PixelPacket *) NULL)
     return;
   range=GetQuantumRange(16UL);
-  SetRedPixelComponent(q,ScaleAnyToQuantum((size_t) (65535.0*
+  SetPixelRed(q,ScaleAnyToQuantum((size_t) (65535.0*
     GetPseudoRandomValue(random_info)+0.5),range));
-  SetGreenPixelComponent(q,ScaleAnyToQuantum((size_t) (65535.0*
+  SetPixelGreen(q,ScaleAnyToQuantum((size_t) (65535.0*
     GetPseudoRandomValue(random_info)+0.5),range));
-  SetBluePixelComponent(q,ScaleAnyToQuantum((size_t) (65535.0*
+  SetPixelBlue(q,ScaleAnyToQuantum((size_t) (65535.0*
     GetPseudoRandomValue(random_info)+0.5),range));
   (void) SyncAuthenticPixels(image,exception);
 }
@@ -173,7 +175,7 @@ static Image *ReadPlasmaImage(const ImageInfo *image_info,
       break;
     for (x=0; x < (ssize_t) image->columns; x++)
     {
-      SetOpacityPixelComponent(q,QuantumRange/2);
+      SetPixelOpacity(q,QuantumRange/2);
       q++;
     }
     if (SyncAuthenticPixels(image,exception) == MagickFalse)
