@@ -55,6 +55,7 @@
 #include "magick/monitor.h"
 #include "magick/monitor-private.h"
 #include "magick/paint.h"
+#include "magick/pixel-accessor.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -63,6 +64,10 @@
 #include "magick/module.h"
 #include "wand/MagickWand.h"
 
+#if defined(__CYGWIN__)
+#undef MAGICKCORE_WMF_DELEGATE
+#endif
+
 #if defined(MAGICKCORE_WMF_DELEGATE)
 #include "libwmf/api.h"
 #include "libwmf/eps.h"
@@ -837,7 +842,7 @@ static void ipa_device_begin(wmfAPI * API)
   DrawSetViewbox(WmfDrawingWand, 0, 0, ddata->image->columns, ddata->image->rows );
 
   (void) FormatLocaleString(comment,MaxTextExtent,"Created by ImageMagick %s",
-    GetMagickVersion((unsigned long *) NULL));
+    GetMagickVersion((size_t *) NULL));
   DrawComment(WmfDrawingWand,comment);
 
   /* Scale width and height to image */
@@ -2262,6 +2267,7 @@ static int util_font_weight( const char* font )
  */
 static float lite_font_stringwidth( wmfAPI* API, wmfFont* font, char* str)
 {
+#if 0
   wmf_magick_t
     *ddata = WMF_MAGICK_GetData(API);
 
@@ -2322,6 +2328,13 @@ static float lite_font_stringwidth( wmfAPI* API, wmfFont* font, char* str)
   image->units = orig_resolution_units;
 
   return stringwidth;
+#else
+  (void) API;
+  (void) font;
+  (void) str;
+
+  return 0;
+#endif
 }
 
 /* Map font (similar to wmf_ipa_font_map) */
@@ -2701,14 +2714,14 @@ static Image *ReadWMFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   /* User specified resolution */
   resolution_y=DefaultResolution;
-  if (image->y_resolution > 0)
+  if (image->y_resolution != 0.0)
     {
       resolution_y = image->y_resolution;
       if (image->units == PixelsPerCentimeterResolution)
         resolution_y *= CENTIMETERS_PER_INCH;
     }
   resolution_x=DefaultResolution;
-  if (image->x_resolution > 0)
+  if (image->x_resolution != 0.0)
     {
       resolution_x = image->x_resolution;
       if (image->units == PixelsPerCentimeterResolution)
@@ -2863,8 +2876,8 @@ static Image *ReadWMFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-       "  Creating canvas image with size %ldx%ld",
-       image->rows,image->columns);
+       "  Creating canvas image with size %lux%lu",(unsigned long) image->rows,
+       (unsigned long) image->columns);
 
   /*
    * Set solid background color
