@@ -42,6 +42,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/cache-view.h"
 #include "magick/cache.h"
@@ -59,6 +60,7 @@
 #include "magick/monitor.h"
 #include "magick/monitor-private.h"
 #include "magick/option.h"
+#include "magick/pixel-accessor.h"
 #include "magick/pixel-private.h"
 #include "magick/quantize.h"
 #include "magick/quantum.h"
@@ -206,7 +208,7 @@ MagickExport MagickBooleanType CycleColormapImage(Image *image,
   status=MagickTrue;
   exception=(&image->exception);
   image_view=AcquireAuthenticCacheView(image,exception);
-#if defined(MAGICKCORE_OPENMP_SUPPORT) 
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
   #pragma omp parallel for schedule(static,4) shared(status) \
     dynamic_number_threads(image,image->columns,image->rows,1)
 #endif
@@ -289,8 +291,7 @@ static int IntensityCompare(const void *x,const void *y)
 
   color_1=(const PixelPacket *) x;
   color_2=(const PixelPacket *) y;
-  intensity=(int) PixelIntensityToQuantum(color_2)-
-    (int) PixelIntensityToQuantum(color_1);
+  intensity=PixelPacketIntensity(color_2)-(int) PixelPacketIntensity(color_1);
   return(intensity);
 }
 
