@@ -345,6 +345,11 @@ MagickExport Image *PingImages(const ImageInfo *image_info,
       sans=AcquireExceptionInfo();
       (void) SetImageInfo(read_info,0,sans);
       sans=DestroyExceptionInfo(sans);
+      if (read_info->number_scenes == 0)
+        {
+          read_info=DestroyImageInfo(read_info);
+          return(PingImage(image_info,exception));
+        }
       (void) CopyMagickString(filename,read_info->filename,MaxTextExtent);
       images=NewImageList();
       extent=(ssize_t) (read_info->scene+read_info->number_scenes);
@@ -453,14 +458,9 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       errno=EPERM;
       (void) ThrowMagickException(exception,GetMagickModule(),PolicyError,
         "NotAuthorized","`%s'",read_info->filename);
+      read_info=DestroyImageInfo(read_info);
       return((Image *) NULL);
     }
-  if ((LocaleNCompare(filename,"fd:",3) == 0) &&
-      (image_info->file == (FILE *) NULL))
-    {
-      read_info->file=fdopen(StringToLong(filename+3),"rb");
-      SetImageInfoFile((ImageInfo *) image_info,read_info->file);
-    }
   /*
     Call appropriate image reader based on image type.
   */
@@ -1062,6 +1062,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
         {
           (void) ThrowMagickException(&image->exception,GetMagickModule(),
             OptionError,"NoClipPathDefined","`%s'",image->filename);
+          write_info=DestroyImageInfo(write_info);
           return(MagickFalse);
         }
       image=image->clip_mask;
@@ -1074,15 +1075,10 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
   if (IsRightsAuthorized(domain,rights,write_info->magick) == MagickFalse)
     {
       sans_exception=DestroyExceptionInfo(sans_exception);
+      write_info=DestroyImageInfo(write_info);
       errno=EPERM;
       ThrowBinaryException(PolicyError,"NotAuthorized",filename);
     }
-  if ((LocaleNCompare(filename,"fd:",3) == 0) &&
-      (image_info->file == (FILE *) NULL))
-    {
-      write_info->file=fdopen(StringToLong(filename+3),"wb");
-      SetImageInfoFile((ImageInfo *) image_info,write_info->file);
-    }
   /*
     Call appropriate image reader based on image type.
   */
